@@ -57,10 +57,8 @@ class APISession(object):
         self._default_timeout = timeout
 
         self.session = requests.Session()
-        self.session.headers = {
-            'Accept': 'application/json',
-            'Content-Type': 'application/x-www-form-urlencoded',
-        }
+        self.session.headers['Accept'] = 'application/json'
+        self.session.headers['Content-Type'] = 'application/x-www-form-urlencoded'
 
         if not access_token and user_login and user_password:
             self.get_access_token()
@@ -200,10 +198,11 @@ class VkAuthorizationError(VkError):
 
 
 class VkAPIMethodError(VkError):
-    __slots__ = ['error']
+    __slots__ = ['error', 'code']
 
     def __init__(self, error):
         self.error = error
+        self.code = error['error_code']
         super(Exception, self).__init__()
 
     def __str__(self):
